%DECODIFICADOR RPE.
%function ep=rpepos(Mc,xmp)
%Entradas:
%Mc:posición RPE codificada.
%xmp:subsecuencia de máxima energía decodificada.
%Salidas:
%ep:excitación residual decodificada.
function ep=rpepos(Mc,xmp)
ep=zeros(1,40);
for i=1:13
   ep(Mc+1+3*(i-1))=xmp(i);
end

